{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Increment all counts in table by pseudocount",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--o-composition-table"
                    },
                    "label": "resulting feature table filename",
                    "type": "string",
                    "default": "comp-table.qza",
                    "id": "#composition-add-pseudocount.cwl/composition"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "label": "feature table to which pseudocounts should be added",
                    "type": "File",
                    "id": "#composition-add-pseudocount.cwl/table"
                }
            ],
            "baseCommand": [
                "qiime",
                "composition",
                "add-pseudocount"
            ],
            "id": "#composition-add-pseudocount.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.composition)"
                    },
                    "id": "#composition-add-pseudocount.cwl/out_comp_table"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Apply ANCOM to identify features that are differentially abundant across groups",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "label": "The feature table to be used for ANCOM computation",
                    "type": "File",
                    "id": "#composition-ancom.cwl/comp_table"
                },
                {
                    "inputBinding": {
                        "prefix": "--o-visualization"
                    },
                    "label": "Resulting visualization filename",
                    "type": "string",
                    "default": "ancom.qzv",
                    "id": "#composition-ancom.cwl/feat_visualization"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-column"
                    },
                    "label": "Column from metadata file or artifact viewable as metadata",
                    "type": "string",
                    "id": "#composition-ancom.cwl/metadata_column"
                },
                {
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "label": "Metadata file or artifact viewable as metadata",
                    "type": "File",
                    "id": "#composition-ancom.cwl/metadata_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.feat_visualization)"
                    },
                    "id": "#composition-ancom.cwl/out_visual"
                }
            ],
            "baseCommand": [
                "qiime",
                "composition",
                "ancom"
            ],
            "id": "#composition-ancom.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Filter samples from table based on frequency and/or metadata",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "label": "Filter string to filter samples by",
                    "default": "BodySite='gut'",
                    "inputBinding": {
                        "prefix": "--p-where"
                    },
                    "id": "#feature-table-filter-samples.cwl/filter_where"
                },
                {
                    "type": "string",
                    "label": "resulting filtered table filename",
                    "inputBinding": {
                        "prefix": "--o-filtered-table"
                    },
                    "id": "#feature-table-filter-samples.cwl/filtered_table_filename"
                },
                {
                    "type": "File",
                    "label": "metadata file or artifact viewable as metadata",
                    "inputBinding": {
                        "prefix": "--m-metadata-file"
                    },
                    "id": "#feature-table-filter-samples.cwl/sample_metadata_file"
                },
                {
                    "type": "File",
                    "label": "feature table to be summarized",
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "id": "#feature-table-filter-samples.cwl/table"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filtered_table_filename)"
                    },
                    "id": "#feature-table-filter-samples.cwl/filtered_table"
                }
            ],
            "baseCommand": [
                "qiime",
                "feature-table",
                "filter-samples"
            ],
            "id": "#feature-table-filter-samples.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "label": "qiime2 identify differentially abundant features",
            "doc": "Differential abundance testing with ANCOM from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "int",
                    "id": "#main/collapse_level"
                },
                {
                    "type": "string",
                    "id": "#main/filter_sample_query"
                },
                {
                    "type": "File",
                    "id": "#main/sample_metadata"
                },
                {
                    "type": "File",
                    "id": "#main/table"
                },
                {
                    "type": "File",
                    "id": "#main/taxonomy"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/ancom_subject_16/out_visual",
                    "id": "#main/ancom_subject_16_visualization_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/ancom_subject_column_gut_table/out_visual",
                    "id": "#main/ancom_visualization_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/gut_table_collapse/out_collapsed_table",
                    "id": "#main/collapsed_table_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/comp_gut_table_l6/out_comp_table",
                    "id": "#main/comp_gut_table_l6_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/pseudocount_gut_table/out_comp_table",
                    "id": "#main/composition_table_file"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_gut_samples/filtered_table",
                    "id": "#main/filter_table_file"
                }
            ],
            "steps": [
                {
                    "run": "#composition-ancom.cwl",
                    "in": [
                        {
                            "source": "#main/comp_gut_table_l6/out_comp_table",
                            "id": "#main/ancom_subject_16/comp_table"
                        },
                        {
                            "valueFrom": "l6-ancom-Subject.qzv",
                            "id": "#main/ancom_subject_16/feat_visualization"
                        },
                        {
                            "valueFrom": "Subject",
                            "id": "#main/ancom_subject_16/metadata_column"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/ancom_subject_16/metadata_file"
                        }
                    ],
                    "out": [
                        "#main/ancom_subject_16/out_visual"
                    ],
                    "id": "#main/ancom_subject_16"
                },
                {
                    "run": "#composition-ancom.cwl",
                    "in": [
                        {
                            "source": "#main/pseudocount_gut_table/out_comp_table",
                            "id": "#main/ancom_subject_column_gut_table/comp_table"
                        },
                        {
                            "valueFrom": "ancom.qzv",
                            "id": "#main/ancom_subject_column_gut_table/feat_visualization"
                        },
                        {
                            "valueFrom": "Subject",
                            "id": "#main/ancom_subject_column_gut_table/metadata_column"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/ancom_subject_column_gut_table/metadata_file"
                        }
                    ],
                    "out": [
                        "#main/ancom_subject_column_gut_table/out_visual"
                    ],
                    "id": "#main/ancom_subject_column_gut_table"
                },
                {
                    "run": "#composition-add-pseudocount.cwl",
                    "in": [
                        {
                            "valueFrom": "comp-gut-table-l6.qza",
                            "id": "#main/comp_gut_table_l6/composition"
                        },
                        {
                            "source": "#main/gut_table_collapse/out_collapsed_table",
                            "id": "#main/comp_gut_table_l6/table"
                        }
                    ],
                    "out": [
                        "#main/comp_gut_table_l6/out_comp_table"
                    ],
                    "id": "#main/comp_gut_table_l6"
                },
                {
                    "run": "#feature-table-filter-samples.cwl",
                    "in": [
                        {
                            "source": "#main/filter_sample_query",
                            "id": "#main/filter_gut_samples/filter_where"
                        },
                        {
                            "valueFrom": "gut-table.qza",
                            "id": "#main/filter_gut_samples/filtered_table_filename"
                        },
                        {
                            "source": "#main/sample_metadata",
                            "id": "#main/filter_gut_samples/sample_metadata_file"
                        },
                        {
                            "source": "#main/table",
                            "id": "#main/filter_gut_samples/table"
                        }
                    ],
                    "out": [
                        "#main/filter_gut_samples/filtered_table"
                    ],
                    "id": "#main/filter_gut_samples"
                },
                {
                    "run": "#taxa-collapse.cwl",
                    "in": [
                        {
                            "source": "#main/collapse_level",
                            "id": "#main/gut_table_collapse/collapse_level"
                        },
                        {
                            "valueFrom": "gut-table-l6.qza",
                            "id": "#main/gut_table_collapse/collapsed_table"
                        },
                        {
                            "source": "#main/filter_gut_samples/filtered_table",
                            "id": "#main/gut_table_collapse/table"
                        },
                        {
                            "source": "#main/taxonomy",
                            "id": "#main/gut_table_collapse/taxonomy_file"
                        }
                    ],
                    "out": [
                        "#main/gut_table_collapse/out_collapsed_table"
                    ],
                    "id": "#main/gut_table_collapse"
                },
                {
                    "run": "#composition-add-pseudocount.cwl",
                    "in": [
                        {
                            "valueFrom": "comp-gut-table.qza",
                            "id": "#main/pseudocount_gut_table/composition"
                        },
                        {
                            "source": "#main/filter_gut_samples/filtered_table",
                            "id": "#main/pseudocount_gut_table/table"
                        }
                    ],
                    "out": [
                        "#main/pseudocount_gut_table/out_comp_table"
                    ],
                    "id": "#main/pseudocount_gut_table"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Collapse groups of features that have the same taxonomic assignment through the specified level",
            "hints": [
                {
                    "$import": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "inputBinding": {
                        "prefix": "--p-level"
                    },
                    "label": "The taxonomic level at which the features should be collapsed",
                    "type": "int",
                    "default": 2,
                    "id": "#taxa-collapse.cwl/collapse_level"
                },
                {
                    "inputBinding": {
                        "prefix": "--o-collapsed-table"
                    },
                    "label": "The resulting feature table, where all features are now taxonomic annotations with the user-specified number of levels",
                    "type": "string",
                    "default": "coll-table.qza",
                    "id": "#taxa-collapse.cwl/collapsed_table"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-table"
                    },
                    "label": "Feature table to be collapsed",
                    "type": "File",
                    "id": "#taxa-collapse.cwl/table"
                },
                {
                    "inputBinding": {
                        "prefix": "--i-taxonomy"
                    },
                    "label": "Taxonomic annotations for features in the provided feature table",
                    "type": "File",
                    "id": "#taxa-collapse.cwl/taxonomy_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.collapsed_table)"
                    },
                    "id": "#taxa-collapse.cwl/out_collapsed_table"
                }
            ],
            "baseCommand": [
                "qiime",
                "taxa",
                "collapse"
            ],
            "id": "#taxa-collapse.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
